# -*- coding: utf-8 -*-

from django.template.defaultfilters import slugify
from django.test import TestCase

from bbcode.bbcode import BBCode
from ldap_inp import LdapClub, LdapAlias
from portailuser.models import Ecole, PortailUser

from .models import Inutilisateur, ArticleBlog, Club, AliasGere
from .views import responsable


class TestInutilisateur(TestCase):
    "Test de l'objet Inutilisateur"

    def test_get_link(self):
        user = Inutilisateur("tétard")
        self.assertEqual(user.get_link(), "<tétard> (inexistant)")


class TestClub(TestCase):
    "Test de l'objet Club"

    def setUp(self):
        self.club = Club.objects.create(
            ecole=Ecole.inp,
            ident="test-inp",
            description="Coucou, tu veux voir ma bite INP ?",
            nom="Test INP",
            blog_act=True,
        )
        self.INPnet = Club(ecole=Ecole.inp, ident="inp-net")

    def test_get_ldap_club(self):
        ldap_club_INPnet = LdapClub.objects.get(cn=self.INPnet.ident_groupe, ecole=self.INPnet.ecole)
        self.assertEqual(self.INPnet.get_ldap_club(), ldap_club_INPnet)

    def test_no_get_ldap_club(self):
        with self.assertRaises(LdapClub.DoesNotExist):
            self.club.get_ldap_club()

    def test_est_membre(self):
        self.assertEqual(self.club.est_membre("totot"), False)

    def test_ident_groupe(self):
        self.assertEqual(self.club.ident_groupe, "test-inp-inp")


class TestArticleBlog(TestCase):
    "Test de l'objet ArticleBlog"

    def setUp(self):
        self.club = Club.objects.create(
            ecole=Ecole.inp,
            ident="test-inp",
            description="Coucou, tu veux voir ma bite INP ?",
            nom="Test INP",
            blog_act=True,
        )
        self.user = PortailUser.objects.create(ecole=Ecole.inp, username="tatat", first_name="Toto", last_name="Tata")
        self.article = ArticleBlog(
            club=self.club,
            titre="Coucou",
            contenu=BBCode("message_attach", "Tu veux voir ma bite ?", from_db=False),
            auteur=self.user,
            adresse=slugify("Coucou"),
        )

        self.article.contenu.validate_attachments("club", self.article.id)
        self.article.save()

    def test_delete(self):
        self.article.delete()


class TestAliasGere(TestCase):
    "Test de l'objet AliasGere"

    def setUp(self):
        self.clubINP = Club.objects.create(
            ecole=Ecole.inp,
            ident="test-inp",
            description="Coucou, tu veux voir ma bite INP ?",
            nom="Test INP",
            blog_act=True,
        )
        self.aliasINP = AliasGere.objects.create(club=self.clubINP, prefixe="test")

    def test_adresse(self):
        self.assertEqual(self.aliasINP.adresse, "test@bde.inp-toulouse.fr")

    def test_alias_ldap(self):
        with self.assertRaises(LdapAlias.DoesNotExist):
            self.aliasINP.alias_ldap()


class TestViews(TestCase):
    "Test de la vue"

    def setUp(self):
        self.uid0 = "totot"  # last_name=Toto, first_name=Tata
        self.uid1 = "magimef"  # last_name=Magimel, first_name=François
        self.titre = "Respo"

        # responsable → uid:str, titre:str, lien_annuaire:bool

    def test_responsable_uid(self):
        "Pas d'uid"
        self.assertEqual(responsable(None, "", False, False), None)

    def test_responsable_ldap(self):
        "Pas de respo dans le LDAP"
        self.assertEqual(
            responsable("2bites", self.titre, False, False),
            "<strong>Respo :</strong> ???",
        )

    def test_responsable_one(self):
        "Un seul respo"
        self.assertEqual(
            responsable(self.uid0, self.titre, False, False),
            "<strong>Respo :</strong> Tata Toto",
        )
        self.assertEqual(
            responsable(self.uid0, self.titre, True, False),
            '<strong>Respo :</strong> <a href="/annuaire/fiche/totot">Tata Toto</a>',
        )

    def test_responsable_many(self):
        "Plusieurs respos"
        self.assertEqual(
            responsable([self.uid0, self.uid1], self.titre, False, False),
            "<strong>Respos :</strong> Tata Toto, François Magimel",
        )
        self.assertEqual(
            responsable([self.uid0, self.uid1], self.titre, True, False),
            '<strong>Respos :</strong> <a href="/annuaire/fiche/totot">Tata Toto</a>, <a href="/annuaire/fiche/magimef">François Magimel</a>',
        )
